# Copyright 1999-2011 Gentoo Foundation
# Distributed under the terms of the GNU General Public License v2
# $Header: /var/cvsroot/gentoo-x86/dev-embedded/avrdude/avrdude-5.11.1.ebuild,v 1.1 2011/09/21 04:29:31 radhermit Exp $

EAPI=4

inherit autotools eutils flag-o-matic toolchain-funcs

DESCRIPTION="AVR Downloader/UploaDEr"
# an Atmel AVR MCU programmer
# AVR Downloader/UploaDEr - is a program for updating the flash, eeprom,
# fuse, and lock bit memories of Atmel AVR microcontrollers.
# It operations with several popular programmers including the STK500, JTAGICE MkII, AVRISP, and others.
# use ftd2xx: Add support for burning a bootloader into an arduino without external programmer (FTDI bitbang mode)

HOMEPAGE="http://www.nongnu.org/avrdude/"
SRC_URI_BASE="http://savannah.nongnu.org/download/avrdude/${PN}"
SRC_URI="${SRC_URI_BASE}/${P}.tar.gz
	doc? ( ${SRC_URI_BASE}/${PN}-doc-${PV}.tar.gz
	${SRC_URI_BASE}/${PN}-doc-${PV}.pdf )"

LICENSE="GPL-2"
SLOT="0"
KEYWORDS="~arm ~amd64 ~ppc ~ppc64 ~x86"
IUSE="doc ftd2xx"

LIBS_DEPEND="
	ftd2xx? ( dev-embedded/libftd2xx )"
RDEPEND="virtual/libusb
	sys-libs/ncurses
	sys-libs/readline"
DEPEND="${RDEPEND}
	${LIBS_DEPEND}"

DOCS="AUTHORS ChangeLog* NEWS README"

src_prepare() {
	epatch "${FILESDIR}"/patch-stk500v2.c.diff
	# Patchfiles from https://savannah.nongnu.org/patch/?6886
	if use ftd2xx ; then
		epatch "${FILESDIR}"/patch-Makefile.in.diff
		epatch "${FILESDIR}"/patch-avr910.c.diff
		epatch "${FILESDIR}"/patch-avrdude.conf.in.diff
		epatch "${FILESDIR}"/patch-config_gram.y.diff
		epatch "${FILESDIR}"/patch-lexer.l.diff
		epatch "${FILESDIR}"/patch-ft245r.c.diff
		epatch "${FILESDIR}"/patch-ft245r.h.diff
		epatch "${FILESDIR}"/patch-serjtag.c.diff
		epatch "${FILESDIR}"/patch-serjtag.h.diff
	fi
	
	# let the build system re-generate these, bug #120194
	rm -f lexer.c config_gram.c config_gram.h
}

src_configure() {
	use ftd2xx && append-flags -g -O2 -DSUPPORT_FT245R

	# add explicitely the path to libftd2xx
	use ftd2xx && LDFLAGS="${LDFLAGS} -L/opt/$(get_libdir)"
	
	export LIBS="-lftd2xx"

	default
}

src_compile() {
	# The automake target for these files does not use tempfiles or create these
	# atomically, confusing a parallel build. So we force them first.
	emake lexer.c config_gram.c config_gram.h
	emake
}

src_install() {
	default

	if use doc ; then
		newdoc "${DISTDIR}/${PN}-doc-${PV}.pdf" avrdude.pdf
		dohtml -r "${WORKDIR}/avrdude-html/"
	fi
	
	use ftd2xx && einfo "Remember to unload FTDI VCP driver before using avrdude with ftdi"
}
